isLandscape property
bool
get
isLandscape
Returns true if the device is in landscape orientation.
Implementation
bool get isLandscape =>
MediaQuery.of(this).orientation == Orientation.landscape;
Returns true if the device is in landscape orientation.
bool get isLandscape =>
MediaQuery.of(this).orientation == Orientation.landscape;