isPortrait property
bool
get
isPortrait
Returns true if the device is in portrait orientation.
Implementation
bool get isPortrait => !isLandscape;
Returns true if the device is in portrait orientation.
bool get isPortrait => !isLandscape;