isTablet property

bool get isTablet

Returns true if the screen width is between 600 and 800 pixels.

This is a common heuristic for tablets and small form factors.

Implementation

bool get isTablet => display.width > 600 && display.width <= 800;