IPainter constructor
IPainter()
Creates an instance of IPainter.
This is an abstract class used to define custom canvas painters for ICanvas.
Implementation
IPainter();
Creates an instance of IPainter.
This is an abstract class used to define custom canvas painters for ICanvas.
IPainter();