onInit abstract method
Override this method to perform setup such as creating animations.
Called only during first initialization.
Implementation
void onInit(TickerProvider vsync);
Override this method to perform setup such as creating animations.
Called only during first initialization.
void onInit(TickerProvider vsync);