paste method

Future<String> paste()

Reads and returns plain text from the system clipboard.

Returns an empty string if the clipboard is empty or null.

Example:

final text = await someObject.paste();
print(text);

Implementation

Future<String> paste() async {
  final data = await Clipboard.getData(Clipboard.kTextPlain);
  return data?.text ?? '';
}