StringExtension extension

An extension on String that adds utility methods for network operations.

on

Properties

isEmail bool

Available on String, provided by the StringExtension extension

Returns true if this string is a valid email address format.
no setter

Methods

copyToClipboard([BuildContext? context, String? message]) → void

Available on String, provided by the StringExtension extension

Copies this string to the clipboard.
fetchJson() Future

Available on String, provided by the StringExtension extension

Fetches and decodes JSON data from the URL represented by this string.