platform library

Provides platform detection utilities (web, Android, iOS, etc.)

Use it to check platform conditions like:

if (isWeb) { ... }
if (isAndroid) { ... }

Properties

isAndroid bool
Returns true if running on an Android device.
no setter
isIOS bool
Returns true if running on an iOS device.
no setter
isLinux bool
Returns true if running on a Linux desktop system.
no setter
isMacOS bool
Returns true if running on a macOS desktop system.
no setter
isWeb bool
Returns true if the current platform is a web environment.
no setter
isWindows bool
Returns true if running on a Windows desktop system.
no setter