isLinux top-level property
bool
get
isLinux
Returns true if running on a Linux desktop system.
Always false in this placeholder.
Implementation
bool get isLinux => false;
Returns true if running on a Linux desktop system.
Always false in this placeholder.
bool get isLinux => false;