isWeb top-level property
bool
get
isWeb
Returns true if the current platform is a web environment.
Always false in this placeholder.
Implementation
bool get isWeb => false;
Returns true if the current platform is a web environment.
Always false in this placeholder.
bool get isWeb => false;