isWindows top-level property
bool
get
isWindows
Returns true if running on a Windows desktop system.
Always false in this placeholder.
Implementation
bool get isWindows => false;
Returns true if running on a Windows desktop system.
Always false in this placeholder.
bool get isWindows => false;