isMobile property
bool
get
isMobile
Returns true if the screen width is less than 600 pixels.
Typically used to determine if the device is a mobile phone.
Implementation
bool get isMobile => display.width < 600;