IEngine class
The main class for initializing and running a Flutter app using iEngine.
This class ensures:
- Flutter binding is initialized
- Persistent storage (
Prefs) is set up - Your provided app widget is run
Example
void main() {
IEngine.run(MyApp());
}
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited